pub struct CandidateScorer;Expand description
Phase 2: Score candidates from a centroid.
For a single query token and centroid, decompress and score all document tokens assigned to that centroid.
Implementations
Sourceimpl CandidateScorer
impl CandidateScorer
Sourcepub fn score(
query_token: &[f32],
centroid_id: usize,
centroid_score: f32,
codec: &ResidualCodec,
sizes: &[usize],
offsets: &[usize],
chunk_ids: &[ChunkId],
token_indices: &[u16],
residuals: &[u8],
bytes_per_residual: usize,
) -> Vec<(ChunkId, u16, f32)>
pub fn score( query_token: &[f32], centroid_id: usize, centroid_score: f32, codec: &ResidualCodec, sizes: &[usize], offsets: &[usize], chunk_ids: &[ChunkId], token_indices: &[u16], residuals: &[u8], bytes_per_residual: usize, ) -> Vec<(ChunkId, u16, f32)>
Score candidates from a centroid for one query token.
Arguments
query_token- Query embedding for this tokencentroid_id- Selected centroid IDcentroid_score- Precomputed q · ccodec- Residual codec for decompressionsizes- Number of tokens per centroidoffsets- Cumulative offsets per centroidchunk_ids- Chunk IDs for all tokenstoken_indices- Token indices within chunksresiduals- Packed residuals for all tokensbytes_per_residual- Bytes per packed residual
Returns
Vector of (ChunkId, token_index, score) for all candidates.
Sourcepub fn score_single(
query_token: &[f32],
centroid_id: usize,
centroid_score: f32,
codec: &ResidualCodec,
residual: &[u8],
) -> f32
pub fn score_single( query_token: &[f32], centroid_id: usize, centroid_score: f32, codec: &ResidualCodec, residual: &[u8], ) -> f32
Score a single candidate.