pub struct ScoreMerger;Expand description
Phase 3: Merge per-token scores into document scores via MaxSim.
MaxSim computes: score(Q, D) = Σ_i max_j(q_i · d_j)
For each query token, find the maximum score with any document token, then sum across query tokens.
Implementations
Sourceimpl ScoreMerger
impl ScoreMerger